==> leoo_junpro-1.0.1.tar.gz: lib/leooimpjunpro/leoomatjunpro/leoomatjunpro.dart <==
import 'dart:async';
import 'dart:core';

import 'package:camera/camera.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:leoo_junpro/generated/l10n.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leooappconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leoonetconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooeventjunpro/leooindexjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooeventjunpro/leoomaineventjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooproviderjunpro/leoouserproviderjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoostringjunpro/leoostylejunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocodeutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocommonutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoodialogutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoomediautilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoonavigatorutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoorechargeutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoovideoutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoowidgetjunpro/leoobuttonwidgetjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoowidgetjunpro/leoocamerapreviewjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoowidgetjunpro/leootextwidgetjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoowidgetjunpro/leoowidgetjunpro/leoonumbertextwidgetjunpro.dart';
import 'package:leoo_junpro/leooimpjunpro/leoocalljunpro/leoovideocalljunpro.dart';
import 'package:leoo_junpro/leooimpjunpro/leoomainjunpro/leoomainjunpro.dart';
import 'package:leoo_junpro/leooimpjunpro/leoomatjunpro/leoomatwaitjunpro.dart';
import 'package:leoo_junpro/leooimpjunpro/leootopjunpro/leootopjunpro.dart';
import 'package:leoo_junpro/leoorouterjunpro.dart';
import 'package:provider/provider.dart';
import 'package:sp_util/sp_util.dart';

import '../../leooflagjunpro/leooutilsjunpro/leoowidgetutilsjunpro.dart';

///房间等待
class LeooMatJunPro extends StatefulWidget {
  const LeooMatJunPro({Key? key}) : super(key: key);

  @override
  _LeooMatchState createState() => _LeooMatchState();
}

class _LeooMatchState extends State<LeooMatJunPro>
    with
        AutomaticKeepAliveClientMixin<LeooMatJunPro>,
        RouteAware,
        WidgetsBindingObserver {
  @override
  bool get wantKeepAlive => true;
  GlobalKey<LeooButtonWidgetState> buttonKey = GlobalKey();
  Timer? timer;
  int lastSize = 0;
  GlobalKey<LeooNumberTextWidgetState> timeKey = GlobalKey();
  late StreamSubscription subscription;

  CameraController? cameraController;

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance?.addObserver(this);
    lastSize = SpUtil.getInt(LeooAppConfigJunPro.leooMatchJunPro,
        defValue: LeooRechargeUtilsJunPro.instance.getRoomSize(lastSize))!;
    subscription = eventBus.on<LeooHomeEventJunPro>().listen((event) {
      if (event.start) {
        initCamera();
      } else {
        timer?.cancel();
      }
    });
    initCamera();
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    if (state == AppLifecycleState.resumed) {
      if (!LeooVideoCallJunPro.leooOpenJunPro) {
        initCamera();
      }
    } else if (state == AppLifecycleState.paused) {
      cameraController?.dispose();
      cameraController = null;
      LeooCodeUtilsJunPro.onSetState(this);
    }
  }

  void initCamera() {
    LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
      if (cameraController != null ||
          LeooMainJunPro.leooCurIndexJunPro != 2 ||
          !LeooVideoUtilsJunPro.instance.isReception) {
        return;
      }
      Future.delayed(const Duration(seconds: 1), () async {
        LeooDialogUtilsJunPro.instance.showPermissionDialogIndex(context,
            (value) async {
          try {
            if (value) {
              LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
                if (cameraController != null ||
                    LeooMainJunPro.leooCurIndexJunPro != 2 ||
                    !LeooVideoUtilsJunPro.instance.isReception) {
                  return;
                }
                cameraController = CameraController(
                    LeooMediaUtilsJunPro.instance.description!,
                    ResolutionPreset.high,
                    enableAudio: false);
                cameraController?.initialize().then((_) {
                  LeooCodeUtilsJunPro.onSetState(this);
                });
                startTimer();
              });
            }
          } catch (e) {
            LeooNetConfigJunPro.leooPrintLogJunPro(e);
          }
        }, 0);
      });
    });
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
    LeooRouterJunPro.leooRouteObserverJunPro
        .subscribe(this, ModalRoute.of(context) as PageRoute<dynamic>);
  }

  @override
  void didPopNext() {
    super.didPopNext();
    initCamera();
  }

  @override
  void didPushNext() {
    super.didPushNext();
    timer?.cancel();
    cameraController?.dispose();
    cameraController = null;
    LeooCodeUtilsJunPro.onSetState(this);
  }

  void startTimer() {
    if (LeooMainJunPro.leooCurIndexJunPro == 2) {
      timer?.cancel();
      timer = Timer.periodic(const Duration(seconds: 3), (timer) {
        LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
          if (LeooMainJunPro.leooCurIndexJunPro != 2 ||
              !LeooVideoUtilsJunPro.instance.isReception) {
            timer.cancel();
            SpUtil.putInt(LeooAppConfigJunPro.leooMatchJunPro, lastSize);
          } else {
            lastSize = LeooRechargeUtilsJunPro.instance.getRoomSize(lastSize);
            SpUtil.putInt(LeooAppConfigJunPro.leooMatchJunPro, lastSize);
            timeKey.currentState?.onSetState(lastSize);
          }
        }, () {
          timer.cancel();
          SpUtil.putInt(LeooAppConfigJunPro.leooMatchJunPro, lastSize);
        });
      });
    }
  }

  @override
  void dispose() {
    WidgetsBinding.instance?.removeObserver(this);
    LeooRouterJunPro.leooRouteObserverJunPro.unsubscribe(this);
    timer?.cancel();
    cameraController?.dispose();
    cameraController = null;
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    super.build(context);
    return Consumer<LeooUserProviderJunPro>(
        builder: (_, LeooUserProviderJunPro userProvider, __) {
      return SafeArea(
        maintainBottomViewPadding: true,
        child: Column(
          children: [
            SizedBox(height: 5.w),
            Row(
              children: [
                SizedBox(width: 15.w),
                Expanded(
                  child: Text(S.of(context).matchCall.toUpperCase(),
                      style: LeooTextJunPro.leooGetTextStyleAppJunPro(
                          24, FontWeight.bold)),
                ),
                Row(
                  children: [
                    IconButton(
                      iconSize: 40.w,
                      padding: const EdgeInsets.all(0),
                      icon: LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                        LeooIconsJunPro.leooMainRankJunPro,
                        width: 40.w,
                        height: 40.w,
                      ),
                      onPressed:
                          LeooNavigatorUtilsJunPro.leooDebounceJunPro(() {
                        LeooNavigatorUtilsJunPro.leooNavigatorPushJunPro(
                            context, const LeooTopJunPro(), 'LeooTopJunPro');
                      }),
                    ),
                    if (userProvider.userEntity.userType == 0)
                      LeooWidgetUtilsJunPro.leooGetMainCoinsWidgetJunPro(
                          context, userProvider.userEntity.amount),
                  ],
                ),
                SizedBox(width: 15.w),
              ],
            ),
            Expanded(
              child: Padding(
                padding: EdgeInsets.all(10.w),
                child: Stack(
                  alignment: Alignment.bottomCenter,
                  children: [
                    Hero(
                      tag: 'LeooMatWaitJunPro',
                      transitionOnUserGestures: true,
                      child: ClipRRect(
                        borderRadius: BorderRadius.circular(20),
                        child: LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                          LeooIconsJunPro.leooLoadPicJunPro,
                          width: 1.sw,
                          height: 1.sh,
                          fit: BoxFit.cover,
                        ),
                      ),
                    ),
                    if (cameraController?.value.isInitialized == true)
                      ClipRRect(
                        borderRadius: BorderRadius.circular(20),
                        child: LeooCameraPreviewJunPro(cameraController!),
                      ),
                    Column(
                      mainAxisSize: MainAxisSize.min,
                      children: [
                        lastSize != 0
                            ? LeooNumberTextWidgetJunPro(
                                timeKey,
                                LeooTextJunPro.leooGetTextStyleJunPro(
                                    40, FontWeight.bold),
                                lastSize)
                            : Text('----',
                                style: LeooTextJunPro.leooGetTextStyleJunPro(
                                    40, FontWeight.bold)),
                        Text(
                          S.of(context).matchPeople,
                          style: LeooTextJunPro.leooGetTextStyleJunPro(
                              16, FontWeight.bold),
                        ),
                        SizedBox(height: 10.w),
                        LeooTextWidgetJunPro(
                          userProvider.userEntity.userType == 1
                              ? S.of(context).matchCallCoins(
                                  LeooAppConfigJunPro.leooMatchingCostJunPro)
                              : S.of(context).coinsMatch(
                                  LeooAppConfigJunPro.leooMatchingCostJunPro),
                          LeooTextJunPro.leooGetTextStyleJunPro(14),
                          iconData:
                              LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                            LeooIconsJunPro.leooCoinsJunPro,
                            width: 20.w,
                            height: 20.w,
                          ),
                          iconPadding: 2.5.w,
                          padding: EdgeInsets.fromLTRB(8.w, 5.w, 10.w, 5.w),
                          decoration: ShapeDecoration(
                              shape: const StadiumBorder(),
                              color: Colors.white.withOpacity(.1)),
                          mainAxisSize: MainAxisSize.min,
                        ),
                        SizedBox(height: 30.w),
                        Padding(
                          padding: EdgeInsets.only(left: 40.w, right: 40.w),
                          child: LeooButtonWidgetJunPro(
                            S.of(context).matchStart,
                            LeooTextJunPro.leooGetTextStyleJunPro(
                                20, FontWeight.bold),
                            shape: const RoundedRectangleBorder(
                              borderRadius:
                                  BorderRadius.all(Radius.circular(20)),
                            ),
                            color: LeooColorsJunPro.leooAppJunPro,
                            colorRight: LeooColorsJunPro.leooApp2JunPro,
                            onPressed:
                                LeooNavigatorUtilsJunPro.leooDebounceJunPro(
                                    () async {
                              if (await LeooMediaUtilsJunPro.instance
                                      .grantedPermissions(context) ==
                                  true) {
                                LeooNavigatorUtilsJunPro
                                    .leooNavigatorPushJunPro(
                                  context,
                                  LeooMatWaitJunPro(
                                      userProvider.userEntity.userType == 0),
                                  'LeooMatchWaitJunPro',
                                  fullscreenDialog: true,
                                  match: true,
                                  center: Offset(.5.sw, .5.sh),
                                );
                              } else {
                                LeooDialogUtilsJunPro.instance
                                    .showPermissionDialog(context, (value) {
                                  if (value) {
                                    LeooNavigatorUtilsJunPro
                                        .leooNavigatorPushJunPro(
                                      context,
                                      LeooMatWaitJunPro(
                                          userProvider.userEntity.userType ==
                                              0),
                                      'LeooMatchWaitJunPro',
                                      fullscreenDialog: true,
                                      match: true,
                                      center: Offset(.5.sw, .5.sh),
                                    );
                                  }
                                });
                              }
                            }),
                          ),
                        ),
                        SizedBox(height: 44.w),
                      ],
                    ),
                  ],
                ),
              ),
            ),
          ],
        ),
      );
    });
  }
}

==> leoo_junpro-2.0.0.tar.gz: lib/leooimpjunpro/leoomatjunpro/leoomatjunpro.dart <==
import 'dart:async';
import 'dart:core';

import 'package:camera/camera.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:leoo_junpro/generated/l10n.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leooappconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leoonetconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooeventjunpro/leooindexjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooeventjunpro/leoomaineventjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooproviderjunpro/leoouserproviderjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoostringjunpro/leoostylejunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocodeutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocommonutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoodialogutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoomediautilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoonavigatorutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoorechargeutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoovideoutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoowidgetjunpro/leoobuttonwidgetjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoowidgetjunpro/leoocamerapreviewjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoowidgetjunpro/leootextwidgetjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoowidgetjunpro/leoowidgetjunpro/leoonumbertextwidgetjunpro.dart';
import 'package:leoo_junpro/leooimpjunpro/leoocalljunpro/leoovideocalljunpro.dart';
import 'package:leoo_junpro/leooimpjunpro/leoomainjunpro/leoomainjunpro.dart';
import 'package:leoo_junpro/leooimpjunpro/leoomatjunpro/leoomatwaitjunpro.dart';
import 'package:leoo_junpro/leooimpjunpro/leootopjunpro/leootopjunpro.dart';
import 'package:leoo_junpro/leoorouterjunpro.dart';
import 'package:provider/provider.dart';
import 'package:sp_util/sp_util.dart';

import '../../leooflagjunpro/leooutilsjunpro/leoowidgetutilsjunpro.dart';

///房间等待
class LeooMatJunPro extends StatefulWidget {
  const LeooMatJunPro({Key? key}) : super(key: key);

  @override
  _LeooMatchState createState() => _LeooMatchState();
}

class _LeooMatchState extends State<LeooMatJunPro>
    with
        AutomaticKeepAliveClientMixin<LeooMatJunPro>,
        RouteAware,
        WidgetsBindingObserver {
  @override
  bool get wantKeepAlive => true;
  GlobalKey<LeooButtonWidgetState> buttonKey = GlobalKey();
  Timer? timer;
  int lastSize = 0;
  GlobalKey<LeooNumberTextWidgetState> timeKey = GlobalKey();
  late StreamSubscription subscription;

  CameraController? cameraController;

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance.addObserver(this);
    lastSize = SpUtil.getInt(LeooAppConfigJunPro.leooMatchJunPro,
        defValue: LeooRechargeUtilsJunPro.instance.getRoomSize(lastSize))!;
    subscription = eventBus.on<LeooHomeEventJunPro>().listen((event) {
      if (event.start) {
        initCamera();
      } else {
        timer?.cancel();
      }
    });
    initCamera();
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    if (state == AppLifecycleState.resumed) {
      if (!LeooVideoCallJunPro.leooOpenJunPro) {
        initCamera();
      }
    } else if (state == AppLifecycleState.paused) {
      cameraController?.dispose();
      cameraController = null;
      LeooCodeUtilsJunPro.onSetState(this);
    }
  }

  void initCamera() {
    LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
      if (cameraController != null ||
          LeooMainJunPro.leooCurIndexJunPro != 2 ||
          !LeooVideoUtilsJunPro.instance.isReception) {
        return;
      }
      Future.delayed(const Duration(seconds: 1), () async {
        LeooDialogUtilsJunPro.instance.showPermissionDialogIndex(context,
            (value) async {
          try {
            if (value) {
              LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
                if (cameraController != null ||
                    LeooMainJunPro.leooCurIndexJunPro != 2 ||
                    !LeooVideoUtilsJunPro.instance.isReception) {
                  return;
                }
                cameraController = CameraController(
                    LeooMediaUtilsJunPro.instance.description!,
                    ResolutionPreset.high,
                    enableAudio: false);
                cameraController?.initialize().then((_) {
                  LeooCodeUtilsJunPro.onSetState(this);
                });
                startTimer();
              });
            }
          } catch (e) {
            LeooNetConfigJunPro.leooPrintLogJunPro(e);
          }
        }, 0);
      });
    });
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
    LeooRouterJunPro.leooRouteObserverJunPro
        .subscribe(this, ModalRoute.of(context) as PageRoute<dynamic>);
  }

  @override
  void didPopNext() {
    super.didPopNext();
    initCamera();
  }

  @override
  void didPushNext() {
    super.didPushNext();
    timer?.cancel();
    cameraController?.dispose();
    cameraController = null;
    LeooCodeUtilsJunPro.onSetState(this);
  }

  void startTimer() {
    if (LeooMainJunPro.leooCurIndexJunPro == 2) {
      timer?.cancel();
      timer = Timer.periodic(const Duration(seconds: 3), (timer) {
        LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
          if (LeooMainJunPro.leooCurIndexJunPro != 2 ||
              !LeooVideoUtilsJunPro.instance.isReception) {
            timer.cancel();
            SpUtil.putInt(LeooAppConfigJunPro.leooMatchJunPro, lastSize);
          } else {
            lastSize = LeooRechargeUtilsJunPro.instance.getRoomSize(lastSize);
            SpUtil.putInt(LeooAppConfigJunPro.leooMatchJunPro, lastSize);
            timeKey.currentState?.onSetState(lastSize);
          }
        }, () {
          timer.cancel();
          SpUtil.putInt(LeooAppConfigJunPro.leooMatchJunPro, lastSize);
        });
      });
    }
  }

  @override
  void dispose() {
    WidgetsBinding.instance.removeObserver(this);
    LeooRouterJunPro.leooRouteObserverJunPro.unsubscribe(this);
    timer?.cancel();
    cameraController?.dispose();
    cameraController = null;
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    super.build(context);
    return Consumer<LeooUserProviderJunPro>(
        builder: (_, LeooUserProviderJunPro userProvider, __) {
      return SafeArea(
        maintainBottomViewPadding: true,
        child: Column(
          children: [
            SizedBox(height: 5.w),
            Row(
              children: [
                SizedBox(width: 15.w),
                Expanded(
                  child: Text(S.of(context).matchCall.toUpperCase(),
                      style: LeooTextJunPro.leooGetTextStyleAppJunPro(
                          24, FontWeight.bold)),
                ),
                Row(
                  children: [
                    IconButton(
                      iconSize: 40.w,
                      padding: const EdgeInsets.all(0),
                      icon: LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                        LeooIconsJunPro.leooMainRankJunPro,
                        width: 40.w,
                        height: 40.w,
                      ),
                      onPressed:
                          LeooNavigatorUtilsJunPro.leooDebounceJunPro(() {
                        LeooNavigatorUtilsJunPro.leooNavigatorPushJunPro(
                            context, const LeooTopJunPro(), 'LeooTopJunPro');
                      }),
                    ),
                    if (userProvider.userEntity.userType == 0)
                      LeooWidgetUtilsJunPro.leooGetMainCoinsWidgetJunPro(
                          context, userProvider.userEntity.amount),
                  ],
                ),
                SizedBox(width: 15.w),
              ],
            ),
            Expanded(
              child: Padding(
                padding: EdgeInsets.all(10.w),
                child: Stack(
                  alignment: Alignment.bottomCenter,
                  children: [
                    Hero(
                      tag: 'LeooMatWaitJunPro',
                      transitionOnUserGestures: true,
                      child: ClipRRect(
                        borderRadius: BorderRadius.circular(20),
                        child: LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                          LeooIconsJunPro.leooLoadPicJunPro,
                          width: 1.sw,
                          height: 1.sh,
                          fit: BoxFit.cover,
                        ),
                      ),
                    ),
                    if (cameraController?.value.isInitialized == true)
                      ClipRRect(
                        borderRadius: BorderRadius.circular(20),
                        child: LeooCameraPreviewJunPro(cameraController!),
                      ),
                    Column(
                      mainAxisSize: MainAxisSize.min,
                      children: [
                        lastSize != 0
                            ? LeooNumberTextWidgetJunPro(
                                timeKey,
                                LeooTextJunPro.leooGetTextStyleJunPro(
                                    40, FontWeight.bold),
                                lastSize)
                            : Text('----',
                                style: LeooTextJunPro.leooGetTextStyleJunPro(
                                    40, FontWeight.bold)),
                        Text(
                          S.of(context).matchPeople,
                          style: LeooTextJunPro.leooGetTextStyleJunPro(
                              16, FontWeight.bold),
                        ),
                        SizedBox(height: 10.w),
                        LeooTextWidgetJunPro(
                          userProvider.userEntity.userType == 1
                              ? S.of(context).matchCallCoins(
                                  LeooAppConfigJunPro.leooMatchingCostJunPro)
                              : S.of(context).coinsMatch(
                                  LeooAppConfigJunPro.leooMatchingCostJunPro),
                          LeooTextJunPro.leooGetTextStyleJunPro(14),
                          iconData:
                              LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                            LeooIconsJunPro.leooCoinsJunPro,
                            width: 20.w,
                            height: 20.w,
                          ),
                          iconPadding: 2.5.w,
                          padding: EdgeInsets.fromLTRB(8.w, 5.w, 10.w, 5.w),
                          decoration: ShapeDecoration(
                              shape: const StadiumBorder(),
                              color: Colors.white.withOpacity(.1)),
                          mainAxisSize: MainAxisSize.min,
                        ),
                        SizedBox(height: 30.w),
                        Padding(
                          padding: EdgeInsets.only(left: 40.w, right: 40.w),
                          child: LeooButtonWidgetJunPro(
                            S.of(context).matchStart,
                            LeooTextJunPro.leooGetTextStyleJunPro(
                                20, FontWeight.bold),
                            shape: const RoundedRectangleBorder(
                              borderRadius:
                                  BorderRadius.all(Radius.circular(20)),
                            ),
                            color: LeooColorsJunPro.leooAppJunPro,
                            colorRight: LeooColorsJunPro.leooApp2JunPro,
                            onPressed:
                                LeooNavigatorUtilsJunPro.leooDebounceJunPro(
                                    () async {
                              if (await LeooMediaUtilsJunPro.instance
                                      .grantedPermissions(context) ==
                                  true) {
                                LeooNavigatorUtilsJunPro
                                    .leooNavigatorPushJunPro(
                                  context,
                                  LeooMatWaitJunPro(
                                      userProvider.userEntity.userType == 0),
                                  'LeooMatchWaitJunPro',
                                  fullscreenDialog: true,
                                  match: true,
                                  center: Offset(.5.sw, .5.sh),
                                );
                              } else {
                                LeooDialogUtilsJunPro.instance
                                    .showPermissionDialog(context, (value) {
                                  if (value) {
                                    LeooNavigatorUtilsJunPro
                                        .leooNavigatorPushJunPro(
                                      context,
                                      LeooMatWaitJunPro(
                                          userProvider.userEntity.userType ==
                                              0),
                                      'LeooMatchWaitJunPro',
                                      fullscreenDialog: true,
                                      match: true,
                                      center: Offset(.5.sw, .5.sh),
                                    );
                                  }
                                });
                              }
                            }),
                          ),
                        ),
                        SizedBox(height: 44.w),
                      ],
                    ),
                  ],
                ),
              ),
            ),
          ],
        ),
      );
    });
  }
}
